import org.junit.jupiter.api.MethodDescriptor;
import org.junit.jupiter.api.MethodOrderer;
import org.junit.jupiter.api.MethodOrdererContext;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.util.*;

public class CustomOrder implements MethodOrderer {
    private final Map<String, Integer> priorities;

    public CustomOrder() {
        this.priorities = readPrioritiesFromCSV("src\\example.csv");
    }

    @Override
    public void orderMethods(MethodOrdererContext context) {
        context.getMethodDescriptors().sort(Comparator.comparingInt(this::getPriority));
        
    }

    private int getPriority(MethodDescriptor descriptor) {
        String methodName = descriptor.getMethod().getName();
        return priorities.getOrDefault(methodName, Integer.MAX_VALUE);
    }

    private Map<String, Integer> readPrioritiesFromCSV(String filePath) {
        Map<String, Integer> priorities = new HashMap<>();
        try (BufferedReader reader = new BufferedReader(new FileReader(filePath))) {
            String line;
            while ((line = reader.readLine()) != null) {
                String[] parts = line.split(",");
                String methodName = parts[0].trim();
                int priority = Integer.parseInt(parts[1].trim());
                priorities.put(methodName, priority);
            }
        } catch (IOException e) {
            System.err.println("Error reading priorities from CSV file: " + e.getMessage());
        }
        return priorities;
    }
}
